@@ -57,18 +57,15 @@ class Accountant:
         blocked_deposit_balance = self.ledger.get_book_balances(
             book_id=self.bank_account['ledger_books']['blocked_balance']['id'],
             asset_id=currency, metadata_filter={'operation': 'DEPOSIT'})
-
         blocked_withdraw_balance = self.ledger.get_book_balances(
             book_id=self.bank_account['ledger_books']['blocked_balance']['id'],
             asset_id=currency, metadata_filter={'operation': 'WITHDRAW'})
-
         main_balance = self.ledger.get_book_balances(book_id=self.bank_account['ledger_books']['main_balance']['id'],
                                                      asset_id=currency)
-
         return {'currency': currency,
-                'blocked_balance_deposit': float(blocked_deposit_balance[currency]),
-                'blocked_balance_withdraw': float(blocked_withdraw_balance[currency]),
-                'main_balance': float(main_balance[currency])}
+                'blocked_balance_deposit': float(blocked_deposit_balance.get(currency, 0)),
+                'blocked_balance_withdraw': float(blocked_withdraw_balance.get(currency, 0)),
+                'main_balance': float(main_balance.get(currency, 0))}
 
     def withdraw_block_amount(self, value: str, currency: str, memo: str):
         log.info("---------Block_Amount_Withdraw----------")
